/*
 * Copyright 2019 StreamThoughts.
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.streamthoughts.azkarra.commons.error;

import org.apache.kafka.streams.errors.StreamsException;
import org.junit.jupiter.api.Test;

import java.util.Collections;
import java.util.List;

import static io.streamthoughts.azkarra.commons.error.DeadLetterTopicExceptionHandlerConfig.*;
import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertTrue;
import static org.junit.jupiter.api.Assertions.assertNull;

class DeadLetterTopicExceptionHandlerConfigTest {

    @Test
    public void shouldAcceptEmptyConfigs() {
        DeadLetterTopicExceptionHandlerConfig config = new DeadLetterTopicExceptionHandlerConfig(Collections.emptyMap());
        assertTrue(config.customHeaders().isEmpty());
        assertTrue(config.getFatalExceptions().isEmpty());
        assertNull(config.outputTopic());
    }

    @Test
    public void shouldAcceptTopicConfig() {
        DeadLetterTopicExceptionHandlerConfig config = new DeadLetterTopicExceptionHandlerConfig(
            Collections.singletonMap(DEAD_LETTER_TOPIC_CONFIG, "test")
        );
        assertEquals("test", config.outputTopic());
    }

    @Test
    public void shouldAcceptFatalExceptionClassListConfig() {
        DeadLetterTopicExceptionHandlerConfig config = new DeadLetterTopicExceptionHandlerConfig(
                Collections.singletonMap(FATAL_ERRORS_CONFIG,
                        Exception.class.getName() + ","+ StreamsException.class.getName())
        );
        List<Class<?>> fatalExceptions = config.getFatalExceptions();
        assertEquals(2, fatalExceptions.size());
    }
}